==> kyt-1.2.3.tgz: package/lib/config/webpack.base.js <==
"use strict";

// All webpack configurations are merged into this
// base. See more about (smart) merging here:
// https://github.com/survivejs/webpack-merge
var path = require('path');

var webpack = require('webpack');

var WebpackBar = require('webpackbar');

var merge = require('webpack-merge');

var findBabelConfigSync = require('find-babel-config').sync;

var _require = require('kyt-utils/paths')(),
    buildPath = _require.buildPath,
    userNodeModulesPath = _require.userNodeModulesPath,
    userRootPath = _require.userRootPath,
    publicSrcPath = _require.publicSrcPath,
    clientAssetsFile = _require.clientAssetsFile,
    loadableAssetsFile = _require.loadableAssetsFile;

var os = require('os');

var fileExtensions = require('./fileExtensions');

module.exports = function (options) {
  var babelrc = findBabelConfigSync(userRootPath);

  if (babelrc) {
    babelrc = babelrc.config;
  }

  return {
    node: {
      __console: false,
      __dirname: false,
      __filename: false
    },
    resolve: {
      extensions: ['.mjs', '.jsx', '.js', '.json'],
      modules: [userNodeModulesPath, path.resolve(__dirname, '../node_modules'), 'node_modules'],
      alias: {
        // This is required so symlinks work during development.
        'webpack/hot/poll': require.resolve('webpack/hot/poll')
      }
    },
    resolveLoader: {
      modules: [userNodeModulesPath, path.resolve(__dirname, '../node_modules'), 'node_modules']
    },
    plugins: [new WebpackBar({
      name: options.type === 'client' ? 'Client' : 'Server'
    }), new webpack.DefinePlugin({
      // Hardcode NODE_ENV at build time so libraries like React get optimized
      'process.env.NODE_ENV': JSON.stringify(process.env.NODE_ENV || options.environment),
      KYT: {
        SERVER_PORT: JSON.stringify(options.serverURL && options.serverURL.port || ''),
        CLIENT_PORT: JSON.stringify(options.clientURL && options.clientURL.port || ''),
        PUBLIC_PATH: JSON.stringify(options.publicPath || ''),
        PUBLIC_DIR: JSON.stringify(options.publicDir || ''),
        EXECUTION_ENVIRONMENT: JSON.stringify(options.type || ''),
        IS_BROWSER: options.type === 'client',
        ASSETS_MANIFEST: JSON.stringify(clientAssetsFile || ''),
        LOADABLE_MANIFEST: JSON.stringify(loadableAssetsFile || '')
      }
    })],
    module: {
      strictExportPresence: true,
      rules: [{
        test: function test(asset) {
          var extensions = new RegExp(fileExtensions);
          var jsCSSExtensions = new RegExp('\\.(js|css)$');
          var isFile = extensions.test(asset);
          var isJSOrCSSInPublic = asset.includes('/src/public/') && jsCSSExtensions.test(asset);
          return isFile || isJSOrCSSInPublic;
        },
        loader: 'file-loader',
        options: {
          name: '[name]-[hash].[ext]',
          publicPath: options.publicPath,
          outputPath: function outputPath(asset) {
            return options.type === 'server' ? "../public/".concat(asset) : asset;
          }
        }
      }, {
        test: /\.(js|jsx)$/,
        loader: 'babel-loader',
        exclude: [/node_modules/, buildPath, publicSrcPath],
        // babel configuration should come from presets defined in the user's
        // .babelrc, unless there's a specific reason why it has to be put in
        // the webpack loader options
        options: merge({
          // this is a loader-specific option and can't be put in a babel preset
          babelrc: false,
          cacheDirectory: options.environment === 'development' ? path.join(os.tmpdir(), 'babel-loader') : false
        }, // if the user hasn't defined a .babelrc, use the kyt default
        babelrc || {
          presets: [require.resolve('babel-preset-kyt-core')]
        })
      }]
    }
  };
};

==> kyt-1.2.5.tgz: package/lib/config/webpack.base.js <==
"use strict";

// All webpack configurations are merged into this
// base. See more about (smart) merging here:
// https://github.com/survivejs/webpack-merge
var path = require('path');

var webpack = require('webpack');

var WebpackBar = require('webpackbar');

var merge = require('webpack-merge');

var findBabelConfigSync = require('find-babel-config').sync;

var _require = require('kyt-utils/paths')(),
    buildPath = _require.buildPath,
    userNodeModulesPath = _require.userNodeModulesPath,
    userRootPath = _require.userRootPath,
    publicSrcPath = _require.publicSrcPath,
    clientAssetsFile = _require.clientAssetsFile,
    loadableAssetsFile = _require.loadableAssetsFile;

var os = require('os');

var fileExtensions = require('./fileExtensions');

module.exports = function (options) {
  var babelrc = findBabelConfigSync(userRootPath);

  if (babelrc) {
    babelrc = babelrc.config;
  }

  return {
    node: {
      __console: false,
      __dirname: false,
      __filename: false
    },
    resolve: {
      extensions: ['.mjs', '.jsx', '.js', '.json', '.ts', '.tsx'],
      modules: [userNodeModulesPath, path.resolve(__dirname, '../node_modules'), 'node_modules'],
      alias: {
        // This is required so symlinks work during development.
        'webpack/hot/poll': require.resolve('webpack/hot/poll')
      }
    },
    resolveLoader: {
      modules: [userNodeModulesPath, path.resolve(__dirname, '../node_modules'), 'node_modules']
    },
    plugins: [new WebpackBar({
      name: options.type === 'client' ? 'Client' : 'Server'
    }), new webpack.DefinePlugin({
      // Hardcode NODE_ENV at build time so libraries like React get optimized
      'process.env.NODE_ENV': JSON.stringify(process.env.NODE_ENV || options.environment),
      KYT: {
        SERVER_PORT: JSON.stringify(options.serverURL && options.serverURL.port || ''),
        CLIENT_PORT: JSON.stringify(options.clientURL && options.clientURL.port || ''),
        PUBLIC_PATH: JSON.stringify(options.publicPath || ''),
        PUBLIC_DIR: JSON.stringify(options.publicDir || ''),
        EXECUTION_ENVIRONMENT: JSON.stringify(options.type || ''),
        IS_BROWSER: options.type === 'client',
        ASSETS_MANIFEST: JSON.stringify(clientAssetsFile || ''),
        LOADABLE_MANIFEST: JSON.stringify(loadableAssetsFile || '')
      }
    })],
    module: {
      strictExportPresence: true,
      rules: [{
        test: function test(asset) {
          var extensions = new RegExp(fileExtensions);
          var jsCSSExtensions = new RegExp('\\.(js|css)$');
          var isFile = extensions.test(asset);
          var isJSOrCSSInPublic = asset.includes('/src/public/') && jsCSSExtensions.test(asset);
          return isFile || isJSOrCSSInPublic;
        },
        loader: 'file-loader',
        options: {
          name: '[name]-[hash].[ext]',
          publicPath: options.publicPath,
          outputPath: function outputPath(asset) {
            return options.type === 'server' ? "../public/".concat(asset) : asset;
          }
        }
      }, {
        test: /\.(js|jsx|ts|tsx)$/,
        loader: 'babel-loader',
        exclude: [/node_modules/, buildPath, publicSrcPath],
        // babel configuration should come from presets defined in the user's
        // .babelrc, unless there's a specific reason why it has to be put in
        // the webpack loader options
        options: merge({
          // this is a loader-specific option and can't be put in a babel preset
          babelrc: false,
          cacheDirectory: options.environment === 'development' ? path.join(os.tmpdir(), 'babel-loader') : false
        }, // if the user hasn't defined a .babelrc, use the kyt default
        babelrc || {
          presets: [require.resolve('babel-preset-kyt-core')]
        })
      }]
    }
  };
};
